@@ -23,7 +23,7 @@ class Storage(driver.Base):
         print "==========================>jss_bucket:"+config.jss_bucket
         print "==========================>jss_domain:"+config.jss_domain
         
-        self._jss = JssClient(self._access_key, self._secret_key, self._domain, '80')
+        self._jss = JssClient(None, self._access_key, self._secret_key, self._domain, None)
         
     def _init_path(self, path=None):
         if path:
@@ -55,7 +55,9 @@ class Storage(driver.Base):
             return output.getvalue()
         except Exception as e:
             print e
-            raise e
+            return ""
+        finally:
+            output.close()
 
     
     @lru.set
